@@ -641,6 +641,9 @@ class AutoReWrite(object):
                 try:
                     out=self.auto_summary(item['text'],auto_sample=True,temperature=temperature)
                 except Exception as e:
+                    # 失败后返回原文
+                    item['results']=item['text']
+                    yield item
 
                     pass
                 # print(out)
