@@ -29,9 +29,9 @@ def auto_cut_markdown(text):
         for ii,img in enumerate(soup.find_all('img')):
 
             img_info={
-                "src":img['src'],
-                "title":img['title'],
-                "alt":img['alt'],
+                "src":img.get("src"),
+                "title":img.get("title"),
+                "alt":img.get("alt"),
                 # "width":img['width'],
                 # "height":img['height']
                 }
