@@ -33,3 +33,20 @@ def dff_text(a, b):
             pass
     # print("".join(text))
     return "".join(text)
+
+
+
+def similar_diff_qk_ratio(str1, str2):
+    """
+    计算相关程度，使用字符串
+    # quick_ratio()比ratio()计算效率更高，计算结果一致
+
+
+    :param str1:
+    :param str2:
+    :return:
+    """
+    try:
+        return difflib.SequenceMatcher(None, str1, str2).quick_ratio()
+    except:
+        return -1
\ No newline at end of file
